=====
Demos
=====
.. toctree::
   :maxdepth: 1

   demo_create_and_tabulate.py
   demo_quadrature.py
   demo_facet_integral.py
   demo_lagrange_variants.py
   demo_dof_transformations.py
   demo_custom_element.py
   demo_custom_element_conforming_cr.py
